@@ -75,11 +75,13 @@ class FunctionsTestCase(SupyTestCase):
     def testIsChannel(self):
         self.failUnless(ircutils.isChannel('#'))
         self.failUnless(ircutils.isChannel('&'))
-        self.failUnless(ircutils.isChannel('+'))
+        self.failIf(ircutils.isChannel('+'))
+        self.failUnless(ircutils.isChannel('+', chantypes='#&+!'))
         self.failUnless(ircutils.isChannel('!'))
         self.failUnless(ircutils.isChannel('#foo'))
         self.failUnless(ircutils.isChannel('&foo'))
-        self.failUnless(ircutils.isChannel('+foo'))
+        self.failIf(ircutils.isChannel('+foo'))
+        self.failUnless(ircutils.isChannel('+foo', chantypes='#&+!'))
         self.failUnless(ircutils.isChannel('!foo'))
         self.failIf(ircutils.isChannel('#foo bar'))
         self.failIf(ircutils.isChannel('#foo,bar'))
